@@ -28,6 +28,7 @@ from .api.invoices import Invoices
 from .api.terms import Terms
 from .api.tax_items import TaxItems
 from .api.tax_groups import TaxGroups
+from .api.price_level import PriceLevel
 from .internal.client import NetSuiteClient
 
 
@@ -74,4 +75,5 @@ class NetSuiteConnection:
         self.tax_items = TaxItems(ns_client)
         self.tax_groups = TaxGroups(ns_client)
         self.credit_memos = CreditMemos(ns_client)
+        self.price_level = PriceLevel(ns_client)
         self.usages = Usage(ns_client)
