@@ -3,6 +3,7 @@
     :class:`NetSuiteLoginError`
     :class:`NetSuiteRequestError`
     :class:`NetSuiteTypeError`
+    :class:`NetSuiteRateLimitError`
 """
 
 class NetSuiteError(Exception):
@@ -38,4 +39,9 @@ class NetSuiteRequestError(NetSuiteError):
 class NetSuiteTypeError(NetSuiteError):
     """Exception raised when requested an invalid netsuite type"""
 
-    pass
\ No newline at end of file
+    pass
+
+class NetSuiteRateLimitError(NetSuiteError):
+    """Exception raised for errors during rate limit requests like get, search, .."""
+
+    pass
